@@ -9,11 +9,17 @@
 #define LANG_H
 
 #include "kcontacts_export.h"
+
+#include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
-#include <QMap>
 
-namespace KContacts {
+class LangTest;
+
+namespace KContacts
+{
+class ParameterMap;
+
 /** @short Class that holds a Language for a contact.
  *  @since 4.14.5
  */
@@ -21,6 +27,10 @@ class KCONTACTS_EXPORT Lang
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Lang &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Lang &);
+    friend class Addressee;
+    friend class VCardTool;
+    friend class ::LangTest;
+
 public:
     Lang();
     Lang(const Lang &other);
@@ -35,8 +45,22 @@ public:
 
     Q_REQUIRED_RESULT bool isValid() const;
 
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
-    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
+#endif
+
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    Q_REQUIRED_RESULT
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
+    QMap<QString, QStringList> parameters() const;
+#endif
 
     Q_REQUIRED_RESULT bool operator==(const Lang &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Lang &other) const;
@@ -44,7 +68,11 @@ public:
     Lang &operator=(const Lang &other);
 
     Q_REQUIRED_RESULT QString toString() const;
+
 private:
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
