@@ -9,12 +9,17 @@
 #define ROLE_H
 
 #include "kcontacts_export.h"
+
 #include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
 
+class RoleTest;
+
 namespace KContacts
 {
+class ParameterMap;
+
 /** @short Class that holds a Role for a contact.
  *  @since 5.3
  */
@@ -22,6 +27,8 @@ class KCONTACTS_EXPORT Role
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Role &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Role &);
+    friend class VCardTool;
+    friend class ::RoleTest;
 
 public:
     Role();
@@ -37,8 +44,22 @@ public:
 
     Q_REQUIRED_RESULT bool isValid() const;
 
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
-    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
+#endif
+
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    Q_REQUIRED_RESULT
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
+    QMap<QString, QStringList> parameters() const;
+#endif
 
     Q_REQUIRED_RESULT bool operator==(const Role &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Role &other) const;
@@ -48,6 +69,9 @@ public:
     Q_REQUIRED_RESULT QString toString() const;
 
 private:
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
